@@ -21,9 +21,9 @@ __all__ = ("DataPointTypeDef", "ForecastTypeDef", "QueryForecastResponseTypeDef"
 DataPointTypeDef = TypedDict("DataPointTypeDef", {"Timestamp": str, "Value": float}, total=False)
 
 ForecastTypeDef = TypedDict(
-    "ForecastTypeDef", {"Predictions": Dict[str, List[DataPointTypeDef]]}, total=False
+    "ForecastTypeDef", {"Predictions": Dict[str, List["DataPointTypeDef"]]}, total=False
 )
 
 QueryForecastResponseTypeDef = TypedDict(
-    "QueryForecastResponseTypeDef", {"Forecast": ForecastTypeDef}, total=False
+    "QueryForecastResponseTypeDef", {"Forecast": "ForecastTypeDef"}, total=False
 )
